@@ -13,6 +13,9 @@ use File::Basename;
 use File::Path;
 
 use JSON;
+use YAML;
+use Config::General ;
+
 use Data::Dumper;
 use File::Copy;
 
@@ -126,15 +129,21 @@ sub task_show {
     local $Data::Dumper::Terse=1;
     print Dumper(task_get($project,$tid)), "\n\n";    
 
-    my $ini_file = sparrow_root."/projects/$project/tasks/$tid/suite.ini";
+    my $ini_file = sparrow_root."/projects/$project/tasks/$tid/suite.cfg";
+    my $ini_file_old = sparrow_root."/projects/$project/tasks/$tid/suite.ini"; 
 
     if (-f $ini_file){
-       print "[test suite ini file - $ini_file]\n\n";
-        open F, $ini_file or confess "can't open $ini_file to read: $!";
-        print join "", <F>;
-        close F;  
-    }else{
-       print "test suite ini file: not found\n"
+       print "[configuration file - $ini_file]\n\n";
+       open F, $ini_file or confess "can't open $ini_file to read: $!";
+       print join "", <F>;
+       close F;  
+    }elsif ( -f $ini_file_old ) {
+       print "[configuration file - $ini_file_old]\n\n";
+       open F, $ini_file_old or confess "can't open $ini_file_old to read: $!";
+       print join "", <F>;
+       close F;  
+    } else{
+       print "configuration file does not exist\n"
     }
 
 
@@ -166,7 +175,14 @@ sub task_ini {
     confess "unknown task" unless  -d sparrow_root."/projects/$project/tasks/$tid";
     confess "please setup your preferable editor via EDITOR environment variable\n" unless editor;
 
-    exec editor.' '.sparrow_root."/projects/$project/tasks/$tid/suite.ini";
+    my $cfg_file_path = sparrow_root."/projects/$project/tasks/$tid/suite.cfg";
+    my $cfg_ini_file_path = sparrow_root."/projects/$project/tasks/$tid/suite.ini";
+
+    if ( ! -f $cfg_file_path and -f  $cfg_ini_file_path ){
+      copy($cfg_ini_file_path,$cfg_file_path) or confess "Copy failed: $!";
+    }
+
+    exec editor.' '.$cfg_file_path;
 
 }
 
@@ -179,7 +195,7 @@ sub task_load_ini {
     confess "unknown project" unless  -d sparrow_root."/projects/$project";
     confess "unknown task" unless  -d sparrow_root."/projects/$project/tasks/$tid";
 
-    my $dest_path = sparrow_root."/projects/$project/tasks/$tid/suite.ini";
+    my $dest_path = sparrow_root."/projects/$project/tasks/$tid/suite.cfg";
     copy($ini_file_path,$dest_path) or confess "Copy failed: $!";
 
     print "loaded test suite ini from $ini_file_path OK \n";
@@ -233,25 +249,55 @@ sub task_run {
     my $cmd = "cd $pdir && export PATH=\$PATH:\$PWD/local/bin && export PERL5LIB=local/lib/perl5:\$PERL5LIB && ";
 
     if ($spj->{plugin_type} eq 'outthentic'){
-      $cmd.="  strun --root ./ --task '[t] ".($task_set->{task_desc})."'"
-    }elsif ( $spj->{plugin_type} eq 'swat' ) {
+      $cmd.="  strun --root ./ --task '[task] ".($task_set->{task_desc})."'"
+    } elsif ( $spj->{plugin_type} eq 'swat' ) {
       $cmd.="  swat ./ ". ($task_set->{host}).' ';
-    }else{
+    } else {
       confess "unsupported plugin type: $spj->{plugin_type}"
     }
 
-
     if ($parameters=~/--yaml\s+(\S+)/){
       my $path = $1;
       $cmd.=" --yaml $path";
-    }elsif ($parameters=~/--json\s+(\S+)/){
+    } elsif ($parameters=~/--json\s+(\S+)/){
       my $path = $1;
       $cmd.=" --json $path";
-    }else{
-      my $path = sparrow_root."/projects/$project/tasks/$tid/suite.ini";
-      $cmd.=" --ini $path" if -f $path;
-    }
+    } else {
+      my $path = sparrow_root."/projects/$project/tasks/$tid/suite.cfg";
+      if (-f $path and -s $path){
+        OK: {
 
+         open CFG, $path or die "cannot open file $path to read: $!";
+         my $str = join "", <CFG>;
+         close CFG;
+
+         eval { decode_json($str) };
+          $cmd.=" --json $path", last OK unless $@;
+  
+          eval { Load($str) };
+          $cmd.=" --yaml $path", last OK unless $@;
+
+          eval {
+
+            Config::General->new(
+              -InterPolateVars => 1 ,
+              -InterPolateEnv  => 1 ,
+              -ConfigFile      => $path 
+            )->getall or confess "file $path is not valid config file";
+  
+          };
+
+          $cmd.=" --ini $path", last OK unless $@;
+
+          confess "bad configuration found at $path";
+
+        }
+
+      }else {
+        my $path = sparrow_root."/projects/$project/tasks/$tid/suite.ini";
+        $cmd.=" --ini $path" if -f $path and -s $path;
+      }
+    }
     if ($cron_mode) {
         $cmd.=" $parameters";
         my $repo_file = sparrow_root.'/cache/report-'.$project.'-'.$tid.'-'.$$.'.txt';
